# Scientific Filesystem (SCI-F)

[![GitHub actions status](https://github.com/vsoch/scif/workflows/ci/badge.svg?branch=master)](https://github.com/vsoch/scif/actions?query=branch%3Amaster+workflow%3Aci)
[![CircleCI](https://circleci.com/gh/vsoch/scif.svg?style=svg)](https://circleci.com/gh/vsoch/scif)
![https://sci-f.github.io/img/logo/scif-slash-green.png](https://sci-f.github.io/img/logo/scif-slash-green.png)

[![asciicast](https://asciinema.org/a/156490.png)](https://asciinema.org/a/156490?speed=2)

The The Scientific Filesystem is an organizational format for scientific software and metadata. 
Our goals are centered around  **consistency**, **transparency**, **programmatic accessibility**, 
and **modularity**. [Read about](https://sci-f.github.io) the format and 
please [contribute](https://github.com/vsoch/scif/issues).

**Citation**

> Vanessa Sochat; The Scientific Filesystem, GigaScience, Volume 7, Issue 5, 1 May 2018, giy023, https://doi.org/10.1093/gigascience/giy023

## What is this?
This module will provide tools for generating and interacting with scientific 
filesystems, optimized for use on a host or inside a container.

## License

This code is licensed under the Mozilla, version 2.0 or later [LICENSE](LICENSE).
